searchData={"items":[{"type":"behaviour","title":"OpentelemetryHoneycombSampler","doc":"Sample with Honeycomb!\n\nThis package provides a handy interface for sampling which is similar to how stock otel samplers work, but with all the messy details abstracted away. Simply pattern match on spans and set a sample rate.\n\nThis package also makes sure that SampleRate is set on the spans as required by Honeycomb. Honeycomb multiplies your span counts by this SampleRate to arrive at a reasonable estimate of the true number of spans. This is also being set on child spans, so those will also be estimated properly by Honeycomb (unlike, I believe, in many other HC samplers).","ref":"OpentelemetryHoneycombSampler.html"},{"type":"behaviour","title":"Getting started - OpentelemetryHoneycombSampler","doc":"Install the package:\n\n```elixir\n# mix.exs\ndef deps do\n  [\n    {:opentelemetry_honeycomb_sampler, \"~> 0.1.0\"}\n  ]\nend\n```\n\nCreate a sampler module:\n\n```elixir\n# my_sampler.ex\n\ndefmodule MySampler do\n  @behaviour OpentelemetryHoneycombSampler\n\n  @impl OpentelemetryHoneycombSampler\n  def description(_config), do: \"MySampler\"\n\n  @impl OpentelemetryHoneycombSampler\n  def setup(_config), do: []\n\n  @impl OpentelemetryHoneycombSampler\n  def sample_rate(\n        _ctx,\n        _trace_id,\n        _links,\n        _span_name,\n        _span_kind,\n        _span_attrs,\n        _sampler_config\n      ) do\n    # 1 # all events will be sent\n    # 2 # 50% of events will be sent\n    # 3 # 33% of events will be sent\n    # 4 # 25% of events will be sent\n    1\n  end\nend\n```\n\nAdd OpentelemetryHoneycombSampler to your `config/config.exs` or similar:\n\n```elixir\n# config/config.exs\n\nconfig :opentelemetry,\n  :sampler,\n  {OpentelemetryHoneycombSampler, %{root: {MySampler, _my_config = %{}}}}\n```\n\nAnd that's all there is to it!","ref":"OpentelemetryHoneycombSampler.html#module-getting-started"},{"type":"behaviour","title":"A note about SampleRate - OpentelemetryHoneycombSampler","doc":"Make sure there is a catch-all function head at the very bottom of your file that returns the general sample rate that you would like to use.\n\nHoneycomb's sample rates are expressed as a positive integer N (1, 2, 3, 1000, etc). Their sample rate means \"1 in N events will be sampled\". In other words, if you return `10` from `should_sample/7`, then one in ten, or 10% of your events, will eventually be sent to Honeycomb.\n\nA sample rate of 1, therefore, results in all of your events being sent to Honeycomb. This is as if you did not configure sampling at all.","ref":"OpentelemetryHoneycombSampler.html#module-a-note-about-samplerate"},{"type":"behaviour","title":"Installation - OpentelemetryHoneycombSampler","doc":"The package can be installed by adding `opentelemetry_honeycomb_sampler` to your list of dependencies in `mix.exs`:\n\nThe docs can be found at  .","ref":"OpentelemetryHoneycombSampler.html#module-installation"},{"type":"behaviour","title":"Thanks - OpentelemetryHoneycombSampler","doc":"Developed partially under contract at [Fairing.co](https://fairing.co).","ref":"OpentelemetryHoneycombSampler.html#module-thanks"},{"type":"callback","title":"OpentelemetryHoneycombSampler.description/1","doc":"","ref":"OpentelemetryHoneycombSampler.html#c:description/1"},{"type":"callback","title":"OpentelemetryHoneycombSampler.sample_rate/7","doc":"","ref":"OpentelemetryHoneycombSampler.html#c:sample_rate/7"},{"type":"callback","title":"OpentelemetryHoneycombSampler.setup/1","doc":"","ref":"OpentelemetryHoneycombSampler.html#c:setup/1"},{"type":"module","title":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator","doc":"Propagate SampleRate so that counts of child spans are accurately shown in Honeycomb","ref":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator.html"},{"type":"macro","title":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator.span_ctx/1","doc":"","ref":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator.html#span_ctx/1"},{"type":"macro","title":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator.span_ctx/2","doc":"","ref":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator.html#span_ctx/2"},{"type":"module","title":"OpentelemetryHoneycombSampler.Sampler","doc":"","ref":"OpentelemetryHoneycombSampler.Sampler.html"}],"content_type":"text/markdown"}